@@ -14,16 +14,17 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-class PythonbuilderException (Exception):
+
+class PythonbuilderException(Exception):
     def __init__(self, message, *arguments):
         self._message = message
         self._arguments = arguments
 
     @property
-    def message (self):
+    def message(self):
         return self._message % self._arguments
 
-    def __str__ (self):
+    def __str__(self):
         return self.message
 
 
@@ -40,7 +41,9 @@ class NoSuchTaskException(PythonbuilderException):
 class CircularTaskDependencyException(PythonbuilderException):
     def __init__(self, first, second=None):
         if second:
-            super(CircularTaskDependencyException, self).__init__("Circular task dependency detected between %s and %s", first, second)
+            super(CircularTaskDependencyException, self).__init__("Circular task dependency detected between %s and %s",
+                                                                  first,
+                                                                  second)
         self.first = first
         self.second = second
 
