@@ -26,6 +26,7 @@ from pybuilder.errors import (CircularTaskDependencyException,
                               NoSuchTaskException)
 from pybuilder.utils import as_list, Timer
 
+
 def as_task_name_list(mixed):
     result = []
     for d in as_list(mixed):
@@ -35,6 +36,7 @@ def as_task_name_list(mixed):
             result.append(str(d))
     return result
 
+
 class Executable(object):
     NAME_PATTERN = re.compile(r"^[a-zA-Z_][a-zA-Z0-9_]+$")
 
@@ -68,6 +70,7 @@ class Executable(object):
 
         self.callable(*arguments)
 
+
 class Action(Executable):
     def __init__(self, name, callable, before=None, after=None, description="", only_once=False):
         super(Action, self).__init__(name, callable, description)
@@ -75,6 +78,7 @@ class Action(Executable):
         self.execute_after = as_task_name_list(after)
         self.only_once = only_once
 
+
 class Task(object):
     def __init__(self, name, callable, dependencies=None, description=""):
         self.name = name
@@ -92,6 +96,7 @@ class Task(object):
             logger.debug("Executing subtask from %s", executable.source)
             executable.execute(argument_dict)
 
+
 class Initializer(Executable):
     def __init__(self, name, callable, environments=None, description=""):
         super(Initializer, self).__init__(name, callable, description)
@@ -200,8 +205,8 @@ class ExecutionManager(object):
 
     def execute_action(self, action, arguments):
         if action.only_once and action in self._actions_executed:
-            self.logger.debug("Action %s has been executed before and is marked as only_once, so will not be executed again",
-                              action.name)
+            message = "Action %s has been executed before and is marked as only_once, so will not be executed again"
+            self.logger.debug(message, action.name)
             return False
 
         self.logger.debug("Executing action '%s' from '%s' before task", action.name, action.source)
@@ -247,7 +252,8 @@ class ExecutionManager(object):
 
         try:
             for dependency in self._task_dependencies[task.name]:
-                self.enqueue_task(execution_plan, dependency.name, circular_check=circular_check if circular_check else task)
+                self.enqueue_task(execution_plan, dependency.name,
+                                  circular_check=circular_check if circular_check else task)
         except CircularTaskDependencyException as e:
             if e.second:
                 raise
