@@ -25,14 +25,16 @@ import unittest
 from pybuilder.core import init, task, description, use_plugin
 from pybuilder.errors import BuildFailedException
 from pybuilder.utils import discover_modules, render_report
-
+from pybuilder.terminal import write_line
 use_plugin("python.core")
 
+
 @init
 def init_test_source_directory(project):
     project.set_property_if_unset("dir_source_unittest_python", "src/unittest/python")
     project.set_property_if_unset("unittest_file_suffix", "_tests.py")
 
+
 @task
 @description("Runs unit tests based on Python's unittest module")
 def run_unit_tests(project, logger):
@@ -62,6 +64,7 @@ def run_unit_tests(project, logger):
         logger.error("Error importing unittests: %s", e)
         raise BuildFailedException("Unable to execute unit tests.")
 
+
 def execute_tests(test_source, suffix):
     output_log_file = StringIO()
 
@@ -73,22 +76,28 @@ def execute_tests(test_source, suffix):
     finally:
         output_log_file.close()
 
+
 def write_report(name, project, logger, result, console_out):
     project.write_report("%s" % name, console_out)
 
     report = {"tests-run": result.testsRun,
               "errors": [],
               "failures": []}
+
     for error in result.errors:
-        report["errors"].append({"test": error[0].id(), "traceback": error[1]})
+        report["errors"].append({"test": error[0].id(),
+                                 "traceback": error[1]})
         logger.error("Test has error: %s", error[0].id())
 
+        if project.verbose:
+            write_line(error[1])
+
     for failure in result.failures:
-        report["failures"].append({"test": failure[0].id(), "traceback": failure[1]})
+        report["failures"].append({"test": failure[0].id(),
+                                   "traceback": failure[1]})
         logger.error("Test failed: %s", failure[0].id())
 
         if project.verbose:
-            sys.stdout.write("\n" + failure[1].replace("Traceback (most recent call last):\n", "")
-                                              .replace("AssertionError", "\nAssertionError"))
+            write_line(failure[1])
 
     project.write_report("%s.json" % name, render_report(report))
